/*! advanced-boilerplate v0.15.4 by Sebastian Software <s.werner@sebastian-software.de> */
import ApolloClient, { createBatchingNetworkInterface, createNetworkInterface } from 'apollo-client';
import { applyMiddleware, combineReducers, compose, createStore } from 'redux';
import thunk from 'redux-thunk';
import React from 'react';
import { propTypes } from 'react-router';
import { connect } from 'react-redux';

/**
 *
 *
 */
function emptyReducer() {
  var previousState = 0 < arguments.length && arguments[0] !== undefined ? arguments[0] : {},
      action = arguments[1];

  return previousState;
}

/**
 *
 *
 */
function emptyMiddleware() {
  return function (next) {
    return function (action) {
      return next(action);
    };
  };
}

/**
 *
 *
 */
function emptyEnhancer(param) {
  return param;
}

var composeEnhancers = "development" === process.env.NODE_ENV && window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || compose;

/**
 *
 *
 */
function ssrReducer() {
  var previousState = 0 < arguments.length && arguments[0] !== undefined ? arguments[0] : {},
      action = arguments[1];

  return previousState;
}

/**
 *
 *
 */
function createReduxStore(_ref) {
  var initialState = _ref.initialState,
      apolloClient = _ref.apolloClient,
      _ref$reducers = _ref.reducers,
      reducers = _ref$reducers === undefined ? {} : _ref$reducers,
      _ref$middlewares = _ref.middlewares,
      middlewares = _ref$middlewares === undefined ? [] : _ref$middlewares,
      _ref$enhancers = _ref.enhancers,
      enhancers = _ref$enhancers === undefined ? [] : _ref$enhancers,
      rootReducer = combineReducers(Object.assign({}, reducers, {
    ssr: ssrReducer,
    apollo: apolloClient ? apolloClient.reducer() : emptyReducer
  })),
      rootEnhancers = composeEnhancers(applyMiddleware(apolloClient ? apolloClient.middleware() : emptyMiddleware, thunk, ...middlewares), ...enhancers),
      store = createStore(rootReducer, initialState, rootEnhancers);


  return store;
}

/**
 *
 *
 */
function createApolloClient(_ref2) {
  var headers = _ref2.headers,
      _ref2$initialState = _ref2.initialState,
      initialState = _ref2$initialState === undefined ? {} : _ref2$initialState,
      _ref2$batchRequests = _ref2.batchRequests,
      batchRequests = _ref2$batchRequests === undefined ? false : _ref2$batchRequests,
      _ref2$trustNetwork = _ref2.trustNetwork,
      trustNetwork = _ref2$trustNetwork === undefined ? true : _ref2$trustNetwork,
      apolloUri = initialState.ssr && initialState.ssr.apolloUri;

  console.log("Creating Apollo Client for URL:", apolloUri);

  if (null != apolloUri) {
    var opts = {
      credentials: trustNetwork ? "include" : "same-origin",

      // transfer request headers to networkInterface so that they're accessible to proxy server
      // Addresses this issue: https://github.com/matthew-andrews/isomorphic-fetch/issues/83
      headers
    };

    if (batchRequests) {
      var networkInterface = createBatchingNetworkInterface({
        uri: apolloUri,
        batchInterval: 10,
        opts
      });
    } else {
      var networkInterface = createNetworkInterface({
        uri: apolloUri,
        opts
      });
    }

    var client = new ApolloClient({
      ssrMode: false,
      addTypename: false,
      networkInterface
    });
  } else {
    var client = new ApolloClient({
      addTypename: false
    });
  }

  return client;
}

// Having this contained within an if statement like this allows webpack
// dead code elimination to take place. It's the small things. :)
var HotLoaderContainer;
if ("development" === process.env.NODE_ENV) {
  HotLoaderContainer = require("react-hot-loader").AppContainer;
} else {
  HotLoaderContainer = function (_ref) {
    var children = _ref.children;

    return React.Children.only(children);
  };
}

var HotLoaderContainer$1 = HotLoaderContainer;

// We use the offline-plugin to generate a service worker. See the webpack
// config for more details.
//
// We need to ensure that the runtime is installed so that the generated
// service worker is executed.
//
// We will only be doing this for production builds.
if ("production" === process.env.NODE_ENV) {
  (function () {
    var OfflinePluginRuntime = require("offline-plugin/runtime");

    // Install the offline plugin, which instantiates our service worker and app
    // cache to support precaching of assets and offline support.
    OfflinePluginRuntime.install({
      onUpdating: () => undefined,

      // When an update is ready we will tell the new SW to take control immediately.
      onUpdateReady: () => OfflinePluginRuntime.applyUpdate(),

      // After the new SW update has been applied we will reload the users page
      // to ensure they are using the latest assets.
      // This only gets run if there were updates available for our cached assets.
      onUpdated: () => window.location.reload(),
      onUpdateFailed: () => undefined
    });
  })();
}

var SET_PATH = "router/SET_PATH";
var RECOVER_PATH = "/pingback/";

var initialState = {};

/**
 * [routerReducer description]
 * @param {[type]} [state=initialState] [description]
 * @param {[type]} action [description]
 * @return {[type]} [description]
 */
function routerReducer() {
  var state = 0 < arguments.length && arguments[0] !== undefined ? arguments[0] : initialState,
      action = arguments[1];

  switch (action.type) {
    case SET_PATH:
      return Object.assign({}, state, { path: action.path });

    default:
      return state;
  }
}

/**
 * [setPath description]
 * @param {[type]} path [description]
 */
function _setPath(path) {
  return {
    type: SET_PATH,
    path
  };
}

/**
 *
 */
class RoutingConnector extends React.Component {
  componentDidMount() {
    this.context.history.listen((_ref) => {
      var pathname = _ref.pathname;

      if (this.props.path !== pathname) {
        this.props.setPath(pathname);
      }
    });

    if (this.context.history.location.pathname === this.props.recoverPath) {
      this.context.history.replace(this.props.path);
    } else {
      this.props.setPath(this.context.history.location.pathname);
    }
  }

  componentWillReceiveProps(nextProps) {
    if (nextProps.path && this.props.path !== nextProps.path) {
      if (this.context.history.location.pathname !== nextProps.path) {
        // Will receive props means they are not yet set, so we have to wait
        // a little before updating the history. Otherwise stuff breaks.
        setTimeout(() => {
          this.context.history.push(nextProps.path);
        }, 0);
      }
    }
  }

  render() {
    return React.createElement(
      "div",
      null,
      this.props.children
    );
  }
}

RoutingConnector.defaultProps = {
  recoverPath: RECOVER_PATH
};

RoutingConnector.contextTypes = {
  history: propTypes.historyContext
};

function mapStateToProps(state) {
  return {
    path: state.router.path
  };
}

function mapDispatchToProps(dispatch) {
  return {
    setPath: path => dispatch(_setPath(path))
  };
}

var RouterConnector = connect(mapStateToProps, mapDispatchToProps)(RoutingConnector);

// This file is just for exporting infrastructure to applications built upon this.

export { createReduxStore, createApolloClient, emptyReducer, emptyMiddleware, emptyEnhancer, ssrReducer, HotLoaderContainer$1 as ReactHotLoader, RouterConnector, routerReducer };
//# sourceMappingURL=browser.modern.esmodule.js.map
