/*! advanced-boilerplate v0.15.4 by Sebastian Software <s.werner@sebastian-software.de> */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var path = require('path');
var express = _interopDefault(require('express'));
var shrinkRay = _interopDefault(require('shrink-ray'));
var uuid = _interopDefault(require('uuid'));
var hpp = _interopDefault(require('hpp'));
var helmet = _interopDefault(require('helmet'));
var React = _interopDefault(require('react'));
var reactDom_server = require('react-dom/server');
var reactRouter = require('react-router');
var codeSplitComponent = require('code-split-component');
var Helmet = _interopDefault(require('react-helmet'));
var reactApollo = require('react-apollo');
var serialize = _interopDefault(require('serialize-javascript'));
var fs = require('fs');
var _toConsumableArray = _interopDefault(require('babel-runtime/helpers/toConsumableArray'));
var ApolloClient = require('apollo-client');
var ApolloClient__default = _interopDefault(ApolloClient);
var redux = require('redux');
var thunk = _interopDefault(require('redux-thunk'));
var _classCallCheck = _interopDefault(require('babel-runtime/helpers/classCallCheck'));
var _createClass = _interopDefault(require('babel-runtime/helpers/createClass'));
var _possibleConstructorReturn = _interopDefault(require('babel-runtime/helpers/possibleConstructorReturn'));
var _inherits = _interopDefault(require('babel-runtime/helpers/inherits'));
var reactRedux = require('react-redux');

// Contains all the configuration specific to our Server.
// Please note that the DefinePlugin of webpack will inline/replace all the
// respective "process.env.*" variables below with the actual values.
// These config values then become a part of the server bundle.

var ABSOLUTE_CLIENT_OUTPUT_PATH = path.resolve(process.env.APP_ROOT, process.env.CLIENT_BUNDLE_OUTPUT_PATH);

var ABSOLUTE_ASSETSINFO_PATH = path.resolve(process.env.APP_ROOT, process.env.CLIENT_BUNDLE_OUTPUT_PATH, process.env.CLIENT_BUNDLE_ASSETS_FILENAME);

var ABSOLUTE_CHUNKMANIFEST_PATH = path.resolve(process.env.APP_ROOT, process.env.CLIENT_BUNDLE_OUTPUT_PATH, process.env.CLIENT_BUNDLE_CHUNK_MANIFEST_FILENAME);

var ABSOLUTE_PUBLIC_PATH = path.resolve(process.env.APP_ROOT, process.env.CLIENT_PUBLIC_PATH);

var config = Object.freeze({
	ABSOLUTE_CLIENT_OUTPUT_PATH: ABSOLUTE_CLIENT_OUTPUT_PATH,
	ABSOLUTE_ASSETSINFO_PATH: ABSOLUTE_ASSETSINFO_PATH,
	ABSOLUTE_CHUNKMANIFEST_PATH: ABSOLUTE_CHUNKMANIFEST_PATH,
	ABSOLUTE_PUBLIC_PATH: ABSOLUTE_PUBLIC_PATH
});

function createExpressServer() {
  // Create our express based server.
  var server = express();

  // Attach a unique "nonce" to every response.  This allows use to declare
  // inline scripts as being safe for execution against our content security policy.
  // @see https://helmetjs.github.io/docs/csp/
  server.use(function (req, res, next) {
    res.locals.nonce = uuid(); // eslint-disable-line no-param-reassign
    next();
  });

  // Don't expose any software information to hackers.
  server.disable("x-powered-by");

  // Prevent HTTP Parameter pollution.
  server.use(hpp());

  // Content Security Policy (CSP)
  //
  // If you are unfamiliar with CSPs then I highly recommend that you do some
  // reading on the subject:
  //  - https://content-security-policy.com/
  //  - https://developers.google.com/web/fundamentals/security/csp/
  //  - https://developer.mozilla.org/en/docs/Web/Security/CSP
  //  - https://helmetjs.github.io/docs/csp/
  //
  // If you are relying on scripts/styles/assets from other servers (internal or
  // external to your company) then you will need to explicitly configure the
  // CSP below to allow for this.  For example you can see I have had to add
  // the polyfill.io CDN in order to allow us to use the polyfill script.
  // It can be a pain to manage these, but it's a really great habit to get in
  // to.
  //
  // You may find CSPs annoying at first, but it is a great habit to build.
  // The CSP configuration is an optional item for helmet, however you should
  // not remove it without making a serious consideration that you do not require
  // the added security.
  var cspConfig = {
    directives: {
      defaultSrc: ["'self'"],

      scriptSrc: [
      // Allow scripts hosted from our application.
      "'self'",

      // Note: We will execution of any inline scripts that have the following
      // nonce identifier attached to them.
      // This is useful for guarding your application whilst allowing an inline
      // script to do data store rehydration (redux/mobx/apollo) for example.
      // @see https://helmetjs.github.io/docs/csp/
      function (req, res) {
        return "'nonce-" + res.locals.nonce + "'";
      },

      // FIXME: Required for eval-source-maps (devtool in webpack)
      "development" === process.env.NODE_ENV ? "'unsafe-eval'" : ""].filter(function (value) {
        return "" !== value;
      }),

      styleSrc: ["'self'", "'unsafe-inline'", "blob:"],
      imgSrc: ["'self'", "data:"],
      fontSrc: ["'self'", "data:"],

      // Note: Setting this to stricter than * breaks the service worker. :(
      // I can't figure out how to get around this, so if you know of a safer
      // implementation that is kinder to service workers please let me know.
      // ["'self'", 'ws:'],
      connectSrc: ["*"],

      // objectSrc: [ "'none'" ],
      // mediaSrc: [ "'none'" ],

      childSrc: ["'self'"]
    }
  };

  if ("development" === process.env.NODE_ENV) {
    // When in development mode we need to add our secondary express server that
    // is used to host our client bundle to our csp config.
    Object.keys(cspConfig.directives).forEach(function (directive) {
      return cspConfig.directives[directive].push("localhost:" + process.env.CLIENT_DEVSERVER_PORT);
    });
  }

  server.use(helmet.contentSecurityPolicy(cspConfig));

  // The xssFilter middleware sets the X-XSS-Protection header to prevent
  // reflected XSS attacks.
  // @see https://helmetjs.github.io/docs/xss-filter/
  server.use(helmet.xssFilter());

  // Frameguard mitigates clickjacking attacks by setting the X-Frame-Options header.
  // @see https://helmetjs.github.io/docs/frameguard/
  server.use(helmet.frameguard("deny"));

  // Sets the X-Download-Options to prevent Internet Explorer from executing
  // downloads in your site’s context.
  // @see https://helmetjs.github.io/docs/ienoopen/
  server.use(helmet.ieNoOpen());

  // Don’t Sniff Mimetype middleware, noSniff, helps prevent browsers from trying
  // to guess (“sniff”) the MIME type, which can have security implications. It
  // does this by setting the X-Content-Type-Options header to nosniff.
  // @see https://helmetjs.github.io/docs/dont-sniff-mimetype/
  server.use(helmet.noSniff());

  // Advanced response compression using a async zopfli/brotli combination
  // https://github.com/aickin/shrink-ray
  server.use(shrinkRay());

  // Configure static serving of our webpack bundled client files.
  server.use(process.env.CLIENT_BUNDLE_HTTP_PATH, express["static"](ABSOLUTE_CLIENT_OUTPUT_PATH, {
    maxAge: process.env.CLIENT_BUNDLE_CACHE_MAXAGE
  }));

  // Configure static serving of our "public" root http path static files.
  server.use(express["static"](ABSOLUTE_PUBLIC_PATH));

  return server;
}

var chunkManifest = "{}";
if ("production" === process.env.MODE) {
  try {
    chunkManifest = fs.readFileSync(ABSOLUTE_CHUNKMANIFEST_PATH, "utf-8");
  } catch (err) {
    console.warn("Could not parse chunkhashes from manifest.json: ", err);
  }
}

var clientAssets = JSON.parse(fs.readFileSync(ABSOLUTE_ASSETSINFO_PATH, "utf-8"));

// Convert the assets json it into an object that contains all the paths to our
// javascript and css files.  Doing this is required as for production
// configurations we add a hash to our filenames, therefore we won't know the
// paths of the output by webpack unless we read them from the assets.json file.
// const chunks = Object.keys(clientAssets).map((key) => clientAssets[key])

function getAssetsForClientChunks(chunks) {
  return chunks.reduce(function (acc, chunkName) {
    var chunkAssets = clientAssets[chunkName];
    if (chunkAssets) {
      if (chunkAssets.js) {
        acc.scripts.push(chunkAssets.js);
      }
      if (chunkAssets.css) {
        acc.styles.push(chunkAssets.css);
      }
    }
    return acc;
  }, { scripts: [], styles: [] });
}

/**
 * Generates HTML link stylesheet tags from a list of stylesheet URLs.
 */
function generateLinkStyleTags(styles) {
  return styles.map(function (uri) {
    return "<link href=\"" + uri + "\" media=\"screen, projection\" rel=\"stylesheet\" />";
  }).join("\n");
}

/**
 * Generates HTML script tags from a list of script URLs.
 */
function generateScriptTags(scripts) {
  return scripts.map(function (uri) {
    return "<script src=\"" + uri + "\"></script>";
  }).join("\n");
}

/**
 * Generates a full HTML page containing the render output of the given react
 * element.
 *
 * @param  rootReactElement
 *   [Optional] The root React element to be rendered on the page.
 * @param  initialState
 *   [Optional] The initial state for the redux store which will be used by the
 *   client to mount the redux store into the desired state.
 *
 * @return The full HTML page in the form of a React element.
 */
function renderPage(_ref) {
  var renderedApp = _ref.renderedApp,
      _ref$initialState = _ref.initialState,
      initialState = _ref$initialState === undefined ? {} : _ref$initialState,
      nonce = _ref.nonce,
      helmet$$1 = _ref.helmet,
      codeSplitState = _ref.codeSplitState,
      chunksForRender = ["vendor", "main"];
  // The chunks that we need to fetch the assets (js/css) for and then include
  // said assets as script/style tags within our html.

  if (codeSplitState && codeSplitState.chunks) {
    // We add all the chunks that our CodeSplitProvider tracked as being used
    // for this render.  This isn't actually required as the rehydrate function
    // of code-split-component which gets executed in our client bundle will
    // ensure all our required chunks are loaded, but its a nice optimisation as
    // it means the browser can start fetching the required files before it's
    // even finished parsing our client bundle entry script.
    // Having the assets.json file available to us made implementing this
    // feature rather arbitrary.
    codeSplitState.chunks.forEach(function (chunk) {
      return chunksForRender.push(chunk);
    });
  }

  // Now we get the assets (js/css) for the chunks.
  var assetsForRender = getAssetsForClientChunks(chunksForRender);

  return "<!doctype html>\n    <html " + (helmet$$1 ? helmet$$1.htmlAttributes.toString() : "") + ">\n      <head>\n        " + (helmet$$1 ? helmet$$1.title.toString() : "") + "\n        " + (helmet$$1 ? helmet$$1.meta.toString() : "") + "\n        " + (helmet$$1 ? helmet$$1.link.toString() : "") + "\n\n        " + generateLinkStyleTags(assetsForRender.styles) + "\n        " + (helmet$$1 ? helmet$$1.style.toString() : "") + "\n      </head>\n      <body>\n        <div id=\"app\">" + (renderedApp || "") + "</div>\n\n        <script nonce=\"" + nonce + "\">" + ("APP_STATE=" + serialize(initialState, { isJSON: true }) + ";" + ("CHUNK_MANIFEST=" + chunkManifest + ";") + (codeSplitComponent.STATE_IDENTIFIER + "=" + serialize(codeSplitState, { isJSON: true }) + ";")) + "</script>\n\n        " + generateScriptTags(assetsForRender.scripts) + "\n        " + (helmet$$1 ? helmet$$1.script.toString() : "") + "\n      </body>\n    </html>";
}

/**
 *
 *
 */
function emptyReducer() {
  var previousState = 0 < arguments.length && arguments[0] !== undefined ? arguments[0] : {},
      action = arguments[1];

  return previousState;
}

/**
 *
 *
 */
function emptyMiddleware() {
  return function (next) {
    return function (action) {
      return next(action);
    };
  };
}

/**
 *
 *
 */
function emptyEnhancer(param) {
  return param;
}

var composeEnhancers = false || redux.compose;

/**
 *
 *
 */
function ssrReducer() {
  var previousState = 0 < arguments.length && arguments[0] !== undefined ? arguments[0] : {},
      action = arguments[1];

  return previousState;
}

/**
 *
 *
 */
function createReduxStore(_ref) {
  var initialState = _ref.initialState,
      apolloClient = _ref.apolloClient,
      _ref$reducers = _ref.reducers,
      reducers = _ref$reducers === undefined ? {} : _ref$reducers,
      _ref$middlewares = _ref.middlewares,
      middlewares = _ref$middlewares === undefined ? [] : _ref$middlewares,
      _ref$enhancers = _ref.enhancers,
      enhancers = _ref$enhancers === undefined ? [] : _ref$enhancers,
      rootReducer = redux.combineReducers(Object.assign({}, reducers, {
    ssr: ssrReducer,
    apollo: apolloClient ? apolloClient.reducer() : emptyReducer
  })),
      rootEnhancers = composeEnhancers.apply(undefined, [redux.applyMiddleware.apply(undefined, [apolloClient ? apolloClient.middleware() : emptyMiddleware, thunk].concat(_toConsumableArray(middlewares)))].concat(_toConsumableArray(enhancers))),
      store = redux.createStore(rootReducer, initialState, rootEnhancers);


  return store;
}

/**
 *
 *
 */
function createApolloClient(_ref2) {
  var headers = _ref2.headers,
      _ref2$initialState = _ref2.initialState,
      initialState = _ref2$initialState === undefined ? {} : _ref2$initialState,
      _ref2$batchRequests = _ref2.batchRequests,
      batchRequests = _ref2$batchRequests === undefined ? false : _ref2$batchRequests,
      _ref2$trustNetwork = _ref2.trustNetwork,
      trustNetwork = _ref2$trustNetwork === undefined ? true : _ref2$trustNetwork,
      apolloUri = initialState.ssr && initialState.ssr.apolloUri;

  console.log("Creating Apollo Client for URL:", apolloUri);

  if (null != apolloUri) {
    var opts = {
      credentials: trustNetwork ? "include" : "same-origin",

      // transfer request headers to networkInterface so that they're accessible to proxy server
      // Addresses this issue: https://github.com/matthew-andrews/isomorphic-fetch/issues/83
      headers: headers
    };

    if (batchRequests) {
      var networkInterface = ApolloClient.createBatchingNetworkInterface({
        uri: apolloUri,
        batchInterval: 10,
        opts: opts
      });
    } else {
      var networkInterface = ApolloClient.createNetworkInterface({
        uri: apolloUri,
        opts: opts
      });
    }

    var client = new ApolloClient__default({
      ssrMode: true,
      addTypename: false,
      networkInterface: networkInterface
    });
  } else {
    var client = new ApolloClient__default({
      addTypename: false
    });
  }

  return client;
}

/**
 * Using Apollo logic to recursively resolve all queries needed for
 * initial rendering. The convention is to use the full JSX tree,
 * traverse it and look for all occurrences of a static `fetchData() => Promise`
 * method which is being executed and waited for.
 *
 * See also:
 * https://www.npmjs.com/package/react-redux-universal-hot-example#server-side-data-fetching
 */
function renderToStringWithData(component) {
  var startLoading = process.hrtime(),
      nanoToMilli = 1000000;

  return reactApollo.getDataFromTree(component).then(function () {
    var loadingRuntime = Math.round(process.hrtime(startLoading)[1] / nanoToMilli),
        startRendering = process.hrtime(),
        result = reactDom_server.renderToString(component),
        renderingRuntime = Math.round(process.hrtime(startRendering)[1] / nanoToMilli);

    console.log("Server: Loading: " + loadingRuntime + "ms Rendering: " + renderingRuntime + "ms");
    return result;
  });
}

// SSR is disabled so we will just return an empty html page and will
// rely on the client to populate the initial react application state.
function renderLight(_ref) {
  var request = _ref.request,
      response = _ref.response,
      nonce = _ref.nonce,
      initialState = _ref.initialState;

  /* eslint-disable no-magic-numbers */
  try {
    var html = renderPage({
      // Provide the redux store state, this will be bound to the window.APP_STATE
      // so that we can rehydrate the state on the client.
      initialState: initialState,

      // Nonce which allows us to safely declare inline scripts.
      nonce: nonce
    });
    response.status(200).send(html);
  } catch (error) {
    response.status(500).send("Error during rendering: " + error + "!: " + error.stack);
  }
}

function renderFull(_ref2) {
  var request = _ref2.request,
      response = _ref2.response,
      nonce = _ref2.nonce,
      AppContainer = _ref2.AppContainer,
      apolloClient = _ref2.apolloClient,
      reduxStore = _ref2.reduxStore,
      routingContext = reactRouter.createServerRenderContext(),
      codeSplitContext = codeSplitComponent.createRenderContext();
  // First create a context for <ServerRouter>, which will allow us to
  // query for the results of the render.


  // We also create a context for our <CodeSplitProvider> which will allow us
  // to query which chunks/modules were used during the render process.

  console.log("Server: Rendering app with data...");

  // Create the application react element.
  renderToStringWithData(React.createElement(
    codeSplitComponent.CodeSplitProvider,
    { context: codeSplitContext },
    React.createElement(
      reactRouter.ServerRouter,
      { location: request.url, context: routingContext },
      React.createElement(
        reactApollo.ApolloProvider,
        { client: apolloClient, store: reduxStore },
        React.createElement(AppContainer, null)
      )
    )
  )).then(function (renderedApp) {
    var reduxState = reduxStore.getState(),
        html = renderPage({
      // Provide the full rendered App react element.
      renderedApp: renderedApp,

      // Provide the redux store state, this will be bound to the window.APP_STATE
      // so that we can rehydrate the state on the client.
      initialState: reduxState,

      // Nonce which allows us to safely declare inline scripts.
      nonce: nonce,

      // Running this gets all the helmet properties (e.g. headers/scripts/title etc)
      // that need to be included within our html. It's based on the rendered app.
      // @see https://github.com/nfl/react-helmet
      helmet: Helmet.rewind(),

      // We provide our code split state so that it can be included within the
      // html, and then the client bundle can use this data to know which chunks/
      // modules need to be rehydrated prior to the application being rendered.
      codeSplitState: codeSplitContext.getState()
    }),
        renderedResult = routingContext.getResult();
    // console.log("Server: Rendered state:", reduxState)

    // Render the app to a string.


    // Get the render result from the server render context.


    console.log("Server: Sending page...");

    /* eslint-disable no-magic-numbers */

    // Check if the render result contains a redirect, if so we need to set
    // the specific status and redirect header and end the response.
    if (renderedResult.redirect) {
      response.status(301).setHeader("Location", renderedResult.redirect.pathname);
      response.end();
      return;
    }

    // If the renderedResult contains a "missed" match then we set a 404 code.
    // Our App component will handle the rendering of an Error404 view.
    // Otherwise everything is all good and we send a 200 OK status.
    response.status(renderedResult.missed ? 404 : 200).send(html);
  })["catch"](function (error) {
    console.error("Error during producing response:", error);
  });
}

/**
 * An express middleware that is capable of doing React server side rendering.
 */
function createUniversalMiddleware(_ref3) {
  var AppContainer = _ref3.AppContainer,
      ssrData = _ref3.ssrData,
      _ref3$batchRequests = _ref3.batchRequests,
      batchRequests = _ref3$batchRequests === undefined ? false : _ref3$batchRequests,
      _ref3$trustNetwork = _ref3.trustNetwork,
      trustNetwork = _ref3$trustNetwork === undefined ? true : _ref3$trustNetwork;

  return function (request, response) {
    if ("string" != typeof response.locals.nonce) {
      throw new Error("A \"nonce\" value has not been attached to the response");
    }
    var nonce = response.locals.nonce,
        initialState = {
      ssr: ssrData
    };

    // Pass object with all Server Side Rendering (SSR) related data to the client


    if (process.env.DISABLE_SSR) {
      renderLight({ request: request, response: response, nonce: nonce, initialState: initialState });
    } else {
      var apolloClient = createApolloClient({
        headers: request.headers,
        initialState: initialState,
        batchRequests: batchRequests,
        trustNetwork: trustNetwork
      }),
          reduxStore = createReduxStore({
        apolloClient: apolloClient,
        initialState: initialState,
        reducers: AppContainer.getReducers(),
        enhancers: AppContainer.getEnhancers(),
        middlewares: AppContainer.getMiddlewares()
      });

      renderFull({ request: request, response: response, nonce: nonce, AppContainer: AppContainer, apolloClient: apolloClient, reduxStore: reduxStore });
    }
  };
}

/* eslint-disable no-magic-numbers */
function addFallbackHandler(server) {
  // Handle 404 errors.
  // Note: the react application middleware hands 404 paths, but it is good to
  // have this backup for paths not handled by the universal middleware. For
  // example you may bind a /api path to express.
  server.use(function (req, res) {
    // eslint-disable-line no-unused-vars,max-len
    res.status(404).send("Sorry, that resource was not found.");
  });

  // Handle all other errors (i.e. 500).
  // Note: You must provide specify all 4 parameters on this callback function
  // even if they aren't used, otherwise it won't be used.
  server.use(function (err, req, res) {
    if (err) {
      console.log(err);
      console.log(err.stack);
    }

    res.status(500).send("Sorry, an unexpected error occurred.");
  });
}

var SET_PATH = "router/SET_PATH";
var RECOVER_PATH = "/pingback/";

var initialState = {};

/**
 * [routerReducer description]
 * @param {[type]} [state=initialState] [description]
 * @param {[type]} action [description]
 * @return {[type]} [description]
 */
function routerReducer() {
  var state = 0 < arguments.length && arguments[0] !== undefined ? arguments[0] : initialState,
      action = arguments[1];

  switch (action.type) {
    case SET_PATH:
      return Object.assign({}, state, { path: action.path });

    default:
      return state;
  }
}

/**
 * [setPath description]
 * @param {[type]} path [description]
 */
function _setPath(path$$1) {
  return {
    type: SET_PATH,
    path: path$$1
  };
}

/**
 *
 */

var RoutingConnector = function (_React$Component) {
  _inherits(RoutingConnector, _React$Component);

  function RoutingConnector() {
    _classCallCheck(this, RoutingConnector);

    return _possibleConstructorReturn(this, (RoutingConnector.__proto__ || Object.getPrototypeOf(RoutingConnector)).apply(this, arguments));
  }

  _createClass(RoutingConnector, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      this.context.history.listen(function (_ref) {
        var pathname = _ref.pathname;

        if (_this2.props.path !== pathname) {
          _this2.props.setPath(pathname);
        }
      });

      if (this.context.history.location.pathname === this.props.recoverPath) {
        this.context.history.replace(this.props.path);
      } else {
        this.props.setPath(this.context.history.location.pathname);
      }
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      var _this3 = this;

      if (nextProps.path && this.props.path !== nextProps.path) {
        if (this.context.history.location.pathname !== nextProps.path) {
          // Will receive props means they are not yet set, so we have to wait
          // a little before updating the history. Otherwise stuff breaks.
          setTimeout(function () {
            _this3.context.history.push(nextProps.path);
          }, 0);
        }
      }
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement(
        "div",
        null,
        this.props.children
      );
    }
  }]);

  return RoutingConnector;
}(React.Component);

RoutingConnector.defaultProps = {
  recoverPath: RECOVER_PATH
};

RoutingConnector.contextTypes = {
  history: reactRouter.propTypes.historyContext
};

function mapStateToProps(state) {
  return {
    path: state.router.path
  };
}

function mapDispatchToProps(dispatch) {
  return {
    setPath: function setPath(path$$1) {
      return dispatch(_setPath(path$$1));
    }
  };
}

var RouterConnector = reactRedux.connect(mapStateToProps, mapDispatchToProps)(RoutingConnector);

// This file is just for exporting infrastructure to applications built upon this.

exports.ServerConfig = config;
exports.createExpressServer = createExpressServer;
exports.createUniversalMiddleware = createUniversalMiddleware;
exports.addFallbackHandler = addFallbackHandler;
exports.renderPage = renderPage;
exports.createReduxStore = createReduxStore;
exports.createApolloClient = createApolloClient;
exports.emptyReducer = emptyReducer;
exports.emptyMiddleware = emptyMiddleware;
exports.emptyEnhancer = emptyEnhancer;
exports.RouterConnector = RouterConnector;
exports.routerReducer = routerReducer;
//# sourceMappingURL=node.classic.commonjs.js.map
